=begin
20171008: modified to show the layers by alphabetic order
=end


module JF
  module AddLayer

    load File.join(File.dirname(__FILE__), 'SKUI', 'embed_skui.rb')
    ::SKUI.embed_in(self)

    OPTIONS = {
      :curr_scene_only => false,
      :curr_scene_vis  => false,
      :curr_scene_hid  => true,
      :new_scene_vis   => true,
      :new_scene_hid   => false
    }

    def self.main

      window_options = {
 #       :title           => "Add Layer v#{VERSION}",	  
        :title           => "Add Layer v??",
        :preferences_key => 'JF\AddLayer',
        :width           => '70cm',
        :height          => 250,
        :resizable => true,
        :modal           => false
      }

      window = SKUI::Window.new(window_options)

      # Layers List
      layers = []
      Sketchup.active_model.layers.each{|layer|
        layers << layer.name unless layer.name == 'Layer0'
      }
	  #mettre par ordre alphabetique glro20171008
	  layers.sort!
      # Cheap Natural Sort
      #layers.sort! {|e| e.split(/(\d+)/).map {|a| a =~ /\d+/ ? a.to_i : a }}

      lst_layers = SKUI::Listbox.new(layers)
      active_layer = Sketchup.active_model.active_layer.name
      #lst_layers.value = @last_layer if @last_layer
      lst_layers.name  = :layer_list
      lst_layers.top   = 5
      lst_layers.left  = 15
      lst_layers.width = 120
      window.add_control(lst_layers)

      btn_AddLayer = SKUI::Button.new("New") {|btn|
        add_layer(btn.window)
      }
      btn_AddLayer.position(140, 5)
      btn_AddLayer.height = 20
      window.add_control(btn_AddLayer)

      # Visible on current Scene only.
      chk_current_scene_only = SKUI::Checkbox.new('Layer visible on selected Scene only', OPTIONS[:curr_scene_only])
      chk_current_scene_only.position(15, 35)
      window.add_control(chk_current_scene_only)

      # Group 1 Default Visibility

      grp_Default = SKUI::Groupbox.new("Layer visibility for existing Scenes")
      grp_Default.position(5, 55)
      grp_Default.right  = 5
      grp_Default.height = 85
      window.add_control(grp_Default)

      rdo_Visible = SKUI::RadioButton.new('Visible', OPTIONS[:curr_scene_vis])
      rdo_Visible.left = 25
      rdo_Visible.on(:change) { |control|
        OPTIONS[:curr_scene_vis] = true
        OPTIONS[:curr_scene_hid] = false
      }
      grp_Default.add_control(rdo_Visible)


      rdo_Hidden = SKUI::RadioButton.new('Hidden', OPTIONS[:curr_scene_hid])
      rdo_Hidden.on( :change ) { |control|
        OPTIONS[:curr_scene_vis] = false
        OPTIONS[:curr_scene_hid] = true
      }
      rdo_Hidden.top  = 40
      rdo_Hidden.left = 25
      grp_Default.add_control(rdo_Hidden)

      # Group 2 New Scene Defaults

      grp_NewPages = SKUI::Groupbox.new('Layer visibility for new Scenes')
      grp_NewPages.position(5, 120)
      grp_NewPages.right  = 5
      grp_NewPages.height = 85
      window.add_control(grp_NewPages)

      rdo_NewVisible = SKUI::RadioButton.new('Visible', OPTIONS[:new_scene_vis])
      rdo_NewVisible.on( :change ) { |control|
        OPTIONS[:new_scene_vis] = true
        OPTIONS[:new_scene_hid] = false
      }
      rdo_NewVisible.left = 25
      grp_NewPages.add_control(rdo_NewVisible)

      rdo_NewHidden = SKUI::RadioButton.new('Hidden', OPTIONS[:new_scene_hid])
      rdo_NewHidden.on( :change ) { |control|
        OPTIONS[:new_scene_vis] = false
        OPTIONS[:new_scene_hid] = true
      }
      rdo_NewHidden.left = 25
      rdo_NewHidden.top  = 40
      grp_NewPages.add_control(rdo_NewHidden)


      # Done Button

      btnDone = SKUI::Button.new('Done') { |control|
        control.window.close
      }
      btnDone.width  = 100
      btnDone.bottom = 5
      btnDone.right  = 5
      window.add_control(btnDone)


      # Add Button
      btnApply = SKUI::Button.new('Apply') { |control|
        apply(control.window)
      }
      btnApply.width  = 100
      btnApply.bottom = 5
      btnApply.left   = 5
      window.add_control(btnApply)

      # Window Ready
      window.on(:ready) {
        if OPTIONS[:curr_scene_only]
          grp_NewPages.enabled = false
          grp_Default.enabled = false
        else
          grp_NewPages.enabled = true
          grp_Default.enabled = true
        end
      }

      chk_current_scene_only.on( :change ) {|control|
        OPTIONS[:curr_scene_only] = control.checked?
        if Sketchup.active_model.pages.length == 0
          UI.messagebox("No Scenes in model.", MB_OK)
          control.checked = false;
          OPTIONS[:curr_scene_only] = false
        else
          if control.checked?
            grp_NewPages.enabled = false
            grp_Default.enabled = false
          else
            grp_NewPages.enabled = true
            grp_Default.enabled = true
          end
        end
      }

      window.show

    end # def main

    def self.add_layer(window)
      new_name = UI.inputbox(["Layer Name:"], [Sketchup.active_model.layers.unique_name()], "Add Layer")
      if new_name
        window[:layer_list].add_item(new_name[0])
        Sketchup.active_model.layers.add(new_name[0])
        window[:layer_list].value = new_name[0]
      end
    end

    def self.apply(window)
      layers = Sketchup.active_model.layers
      pages  = Sketchup.active_model.pages
      layer_name = window[:layer_list].value
      return unless layer_name
      layer = layers[layer_name]
      #@last_layer = layer_name
      Sketchup.active_model.start_operation("Modify Layer Behavior", true)
      if OPTIONS[:curr_scene_only]
        layer.page_behavior = LAYER_IS_HIDDEN_ON_NEW_PAGES
        pages.each { |page| page.set_visibility(layer, false) }
        pages.selected_page.set_visibility(layer, true)
      else
        if OPTIONS[:curr_scene_vis]
          op1 = LAYER_VISIBLE_BY_DEFAULT
          pages.each{|page| page.set_visibility(layer, true)}
        else
          op1 = LAYER_HIDDEN_BY_DEFAULT
          pages.each{|page| page.set_visibility(layer, false)}
        end
        if OPTIONS[:new_scene_vis]
          op2 = LAYER_IS_VISIBLE_ON_NEW_PAGES
        else
          op2 = LAYER_IS_HIDDEN_ON_NEW_PAGES
        end
        flag = op2
        layer.page_behavior = flag
      end
      Sketchup.active_model.commit_operation
    end

    if defined?(JF.menu)
      menu = JF.menu(self)
    else
      menu = UI.menu('Plugins')
    end
    menu.add_item("JF Add Layer") { JF::AddLayer.main() }

  end # mod AddLayer
end # mod JF
